@@ -60,6 +60,9 @@ Base::Base(unsigned int d, Base_Prior *prior, Model *model)
   pcopy = false;
 
   OUTFILE = model->Outfile(&verb);
+
+  /* annleaing temper comes from model */
+  itemp = model->iTemp();
 } 
 
 
@@ -86,6 +89,9 @@ Base::Base(double **X, double *Z, Base *old)
   prior = old->prior->Dup();
   pcopy = true;
 
+  /* copy the importance annealing temperature */
+  itemp = old->itemp;
+
   /* things that must be NULL */
   XX = NULL;
   nn = 0;
@@ -138,6 +144,19 @@ BASE_MODEL Base::BaseModel(void)
 }
 
 
+/*
+ * BasePrior:
+ *
+ * return the prior used by this base
+ *
+ */
+
+Base_Prior* Base::Prior(void)
+{
+  return prior;
+}
+
+
 /*
  * Base_Prior:
  * 
