@@ -151,7 +151,8 @@ void MrMatern::Init(double *dmrmat)
  */
 
 bool MrMatern::DrawNug(unsigned int n, double **X, double **F, double *Z, double *lambda, 
-		       double **bmu, double **Vb, double tau2, double itemp, void *state)
+		       double **bmu, double **Vb, double tau2, double itemp, bool cart,
+		       void *state)
 {
   bool success = false;
   MrGp_Prior *gp_prior = (MrGp_Prior*) base_prior;
@@ -164,9 +165,10 @@ bool MrMatern::DrawNug(unsigned int n, double **X, double **F, double *Z, double
   /* make the draw */
   double nug_new = 
     nug_draw_margin(n, col, nug, F, Z, K, log_det_K, *lambda, Vb, K_new, Ki_new, 
-		    Kchol_new, &log_det_K_new, &lambda_new, Vb_new, bmu_new, gp_prior->get_b0(), 
-		    gp_prior->get_Ti(), gp_prior->get_T(), tau2, prior->NugAlpha(), prior->NugBeta(), 
-		    gp_prior->s2Alpha(), gp_prior->s2Beta(), (int) linear, itemp, state);
+		    Kchol_new, &log_det_K_new, &lambda_new, Vb_new, bmu_new, 
+		    gp_prior->get_b0(), gp_prior->get_Ti(), gp_prior->get_T(), tau2, 
+		    prior->NugAlpha(), prior->NugBeta(), gp_prior->s2Alpha(), 
+		    gp_prior->s2Beta(), (int) linear, itemp, (int) cart, state);
   
   /* did we accept the draw? */
   if(nug_new != nug) { nug = nug_new; success = true; swap_new(Vb, bmu, lambda); }
@@ -248,8 +250,8 @@ void MrMatern::Update(unsigned int n1, unsigned int n2, double **K, double **X,
  */
 
 int MrMatern::Draw(unsigned int n, double **F, double **X, double *Z, 
-	      double *lambda, double **bmu, double **Vb, double tau2, 
-	      double itemp, void *state)
+		   double *lambda, double **bmu, double **Vb, double tau2, 
+		   double itemp, bool cart, void *state)
 {
   int success = 0;
   bool lin_new;
@@ -257,7 +259,7 @@ int MrMatern::Draw(unsigned int n, double **F, double **X, double *Z,
 
   /* sometimes skip this Draw for linear models for speed */
   if(linear && runi(state) > 0.5) 
-    return DrawNug(n, X, F, Z, lambda, bmu, Vb, tau2, itemp, state);
+    return DrawNug(n, X, F, Z, lambda, bmu, Vb, tau2, itemp, cart, state);
 
   /* proppose linear or not */
   if(prior->Linear()) lin_new = true;
@@ -295,7 +297,7 @@ int MrMatern::Draw(unsigned int n, double **F, double **X, double *Z,
 			   gp_prior->get_b0(), gp_prior->get_Ti(), gp_prior->get_T(), tau2, 
 			   nug, nu, bk, nb, q_bak/q_fwd, ep->DAlpha(), ep->DBeta(), 
 			   gp_prior->s2Alpha(), gp_prior->s2Beta(), (int) lin_new, 
-			   itemp, state);
+			   itemp, (int) cart, state);
   }
   
   /* did we accept the new draw? */
@@ -310,7 +312,7 @@ int MrMatern::Draw(unsigned int n, double **F, double **X, double *Z,
   if(dreject >= REJECTMAX) return -2;
 
   /* draw nugget */
-  bool changed = DrawNug(n, X, F, Z, lambda, bmu, Vb, tau2, itemp, state);
+  bool changed = DrawNug(n, X, F, Z, lambda, bmu, Vb, tau2, itemp, cart, state);
   success = success || changed;
   
   return success;
